$AssetsSharedFlagsGen class
Properties
-
china
→ String
-
File path: assets/shared/flags/china.svg
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
india
→ String
-
File path: assets/shared/flags/india.svg
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
saudi
→ String
-
File path: assets/shared/flags/saudi.svg
no setter
-
thailand
→ String
-
File path: assets/shared/flags/thailand.svg
no setter
-
uk
→ String
-
File path: assets/shared/flags/uk.svg
no setter
-
values
→ List<String>
-
List of all assets
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited