$AssetsSharedSvgGen class

Constructors

$AssetsSharedSvgGen()
const

Properties

adultFemale String
File path: assets/shared/svg/adult_female.svg
no setter
adultMale String
File path: assets/shared/svg/adult_male.svg
no setter
childFemale String
File path: assets/shared/svg/child_female.svg
no setter
childMale String
File path: assets/shared/svg/child_male.svg
no setter
hashCode int
The hash code for this object.
no setterinherited
icBenefit1 String
File path: assets/shared/svg/ic_benefit_1.svg
no setter
icComprehensive String
File path: assets/shared/svg/ic_comprehensive.svg
no setter
icPencil String
File path: assets/shared/svg/ic_pencil.svg
no setter
icPremium String
File path: assets/shared/svg/ic_premium.svg
no setter
icStandard String
File path: assets/shared/svg/ic_standard.svg
no setter
icWhatYouPay String
File path: assets/shared/svg/ic_what_you_pay.svg
no setter
icWhatYouRec String
File path: assets/shared/svg/ic_what_you_rec.svg
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited