$LibSmartuiGen class

Constructors

$LibSmartuiGen()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tsonComplexSample String
File path: lib/smartui/tson_complex_sample.json
no setter
tsonSimpleSample String
File path: lib/smartui/tson_simple_sample.json
no setter
values List<String>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited