S360fCommonColors mixin
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- colBackground → const Color
- colBackgroundStatusError → const Color
- colBackgroundStatusInfo → const Color
- colBackgroundStatusSuccess → const Color
- colBackgroundStatusWarning → const Color
- colBlack → const Color
- colDisable → const Color
- colDivider → const Color
- colError → const Color
- colHint → const Color
- colIconActionEnabled → const Color
- colIconServiceCommon → const Color
- colOutline → const Color
- colPageBackground → const Color
- colTextPrimary → const Color
- colTextSecondary → const Color
- colTextStatusError → const Color
- colTextStatusInfo → const Color
- colTextStatusSuccess → const Color
- colTextStatusWarning → const Color
- colWhite → const Color
- gaugeGreenColor → const Color
- gaugeRedColor → const Color
- gaugeYellowColor → const Color