S360fColorsExtension class

Inheritance
Annotations

Constructors

S360fColorsExtension({Color success = Colors.green, Color successContainer = Colors.greenAccent, Color successFixed = Colors.green, Color onSuccess = Colors.white, Color onSuccessContainer = Colors.green, Color onSuccessFixed = Colors.white, Color info = Colors.blue, Color infoContainer = Colors.blueAccent, Color onInfo = Colors.white, Color onInfoContainer = Colors.blue, Color misc1 = Colors.grey, Color misc2 = Colors.grey, Color misc3 = Colors.grey, Color misc4 = Colors.grey, Color misc5 = Colors.grey, Color misc6 = Colors.grey})
const
S360fColorsExtension.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
info → Color
final
infoContainer → Color
final
misc1 → Color
final
misc2 → Color
final
misc3 → Color
final
misc4 → Color
final
misc5 → Color
final
misc6 → Color
final
onInfo → Color
final
onInfoContainer → Color
final
onSuccess → Color
final
onSuccessContainer → Color
final
onSuccessFixed → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → Color
final
successContainer → Color
final
successFixed → Color
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Color? success, Color? successContainer, Color? onSuccess, Color? onSuccessContainer, Color? info, Color? infoContainer, Color? onInfo, Color? onInfoContainer}) → S360fColorsExtension
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<S360fColorsExtension>? other, double t) → S360fColorsExtension
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited