ThemeConfig class

Constructors

ThemeConfig({required ColorScheme colorScheme, required AppAssets appAssets, S360fColorsExtension s360fColors = const S360fColorsExtension()})
ThemeConfig.fromJson(Map<String, dynamic> json)
factory

Properties

appAssets → AppAssets
final
colorScheme → ColorScheme
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s360fColors → S360fColorsExtension
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited