FormController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • FormController
Implemented types

Constructors

FormController({Map<String, dynamic>? initialData})

Properties

fieldKeys → Map<String, GlobalKey<State<StatefulWidget>>>
final
formData ↔ RxMap<String, dynamic>
getter/setter pair
formErrors → RxMap<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
no setterinherited
initialized → bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed → bool
Checks whether the controller has already been closed.
no setterinherited
isEditing → RxBool
final
isMobile ↔ bool
getter/setter pair
isWeb ↔ bool
getter/setter pair
listeners → int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
buildNestedDefaultValues(List<FormFieldModel> fields) → void
clearAllData() → void
clearFormErrors() → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getFormValidationState({required List<FormFieldModel> fields, Map<String, dynamic>? formData, String prefix = ''}) → FormValidationState
Validates the form and returns one of three possible states:
getReactiveFieldValue(String fieldKey) → dynamic
hasErrors() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called when this controller is disposed
override
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeArrayItem(String arrayPath, int removedIndex, String fullFieldKey) → void
Removes an array item and all associated errors, field keys, and form data
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
toString() → String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateReactiveField({required String fieldKey, required FormFieldModel field, dynamic value}) → void
validateNestedForm({required List<FormFieldModel> fields, Map<String, dynamic>? formData, bool skipValidation = false, String prefix = ''}) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited