FormFieldModel class

Constructors

FormFieldModel({required String id, required String type, required String label, String role = '', Object? value, String? placeholder, String? uiType, bool required = false, bool toggle = false, List<ValidationRule>? validations, Map<String, dynamic>? props, List<FormFieldModel>? children, String? parentId, bool isSummary = false, bool isPayment = false, bool modeSwitch = false, bool isPackageSelection = false, int? minFields, int? maxFields, FormFieldModel? template, List<DependencyRule>? dependencies, bool isLayout = false})
FormFieldModel.fromJson(Map<String, dynamic> json)
factory

Properties

children ↔ List<FormFieldModel>?
getter/setter pair
dependencies → List<DependencyRule>?
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isCardLayout → bool
no setter
isLayout → bool
final
isPackageSelection → bool
final
isPayment → bool
final
isSummary → bool
final
label ↔ String
getter/setter pair
maxFields → int?
final
minFields → int?
final
modeSwitch → bool
final
parentId ↔ String?
getter/setter pair
placeholder → String?
final
props → Map<String, dynamic>?
final
required ↔ bool
getter/setter pair
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → FormFieldModel?
final
toggle ↔ bool
getter/setter pair
type ↔ String
getter/setter pair
uiType → String?
final
validations → List<ValidationRule>?
final
value ↔ Object?
getter/setter pair

Methods

getAlignment() → CrossAxisAlignment
getBackgroundColor(BuildContext context) → Color
getDefaultValueIfAvailable() → dynamic
getWrapAlignment(bool leftAlign) → WrapAlignment
isExpandGroup() → bool
isForceSingleColumn() → bool
isFull() → bool
isGroup() → bool
isHalf() → bool
isMaturity() → bool
isPrimaryRole() → bool
isSecondaryRole() → bool
isToggleGroup() → bool
isViewOnly(bool defaultViewMode) → bool
isVisible() → bool
noOfColumns(int defaultValue) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited