StepperModel class

Constructors

StepperModel({String? label, List<FormFieldModel>? fields, String? id, Map<String, dynamic>? props})
StepperModel.fromJson(Map<String, dynamic> json)
factory

Properties

fields → List<FormFieldModel>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
label → String?
final
props → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited