FormLayout class

Constructors

FormLayout()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildLayout({required FormFieldModel field, List<Widget>? children = const [], void onActionInteraction(FormFieldModel field)?, List<NestedContext>? contexts, Map<String, dynamic>? formData}) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getColSpacing(FormFieldModel field, {String? propName}) → double
getColsSetting(FormFieldModel field, {String? propName}) → S360fGridColSize
getLayoutPadding(FormFieldModel field) → EdgeInsets
getRowSpacing(FormFieldModel field, {String? propName}) → double