S360fScreenSize enum

Inheritance
Available extensions

Values

xs → const S360fScreenSize
const S360fScreenSize(576, 'xs')
sm → const S360fScreenSize
const S360fScreenSize(769, 'sm')
md → const S360fScreenSize
const S360fScreenSize(1200, 'md')
lg → const S360fScreenSize
const S360fScreenSize(1400, 'lg')
xl → const S360fScreenSize
const S360fScreenSize(1800, 'xl')
xxl → const S360fScreenSize
const S360fScreenSize(4000, 'xxl')

Properties

breakpointName → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDesktop → bool
no setter
isLaptop → bool
no setter
isMiniDesktop → bool
no setter
isMobile → bool
no setter
isTablet → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The max width of a breakpoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

list ↔ List<S360fScreenSize>
getter/setter pair

Static Methods

getTypeFromWidth(double width) → S360fScreenSize

Constants

values → const List<S360fScreenSize>
A constant List of the values in this enum, in order of their declaration.