DynamicTableModel class

Constructors

DynamicTableModel(Map<String, dynamic> data)
DynamicTableModel.fromJson(Map<String, dynamic> json)
factory

Properties

data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValue(String key) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited