TableStructure class

Constructors

TableStructure({required String key, required String title, required bool isShowing, bool isDisable = false, double columnFlex = 1})
TableStructure.fromJson(Map<String, dynamic> json)
factory

Properties

columnFlex → double
final
hashCode → int
The hash code for this object.
no setterinherited
isDisable ↔ bool
getter/setter pair
isShowing ↔ bool
getter/setter pair
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited