S360fDataTable class

Inheritance
Available extensions

Constructors

S360fDataTable({required List<DataColumn> columns, required List<DataRow> rows, required int currentPage, required int totalItems, required void onPageChanged(int), void onSelect(bool?)?, void onChanged(String)?, int sortColumnIndex = 0, bool sortAscending = true, Widget filterBuilder(BuildContext)?, Widget settingsBuilder(BuildContext)?, List<Widget>? actions, String? searchValue, Key? key})
const

Properties

actions → List<Widget>?
final
columns → List<DataColumn>
final
currentPage → int
final
filterBuilder → Widget Function(BuildContext)?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → void Function(String)?
final
onPageChanged → void Function(int)
final
onSelect → void Function(bool?)?
final
rows → List<DataRow>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchValue → String?
final
settingsBuilder → Widget Function(BuildContext)?
final
sortAscending → bool
final
sortColumnIndex → int
final
totalItems → int
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<S360fDataTable>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited