S360fLineChart class

Inheritance
Available extensions

Constructors

S360fLineChart({required List<LineChartBarData> lineBarsData, required List<Map<String, dynamic>> toolTipKeys, required double convertedValue(double), double? maxValue, double? minValue, void onRangeChanged(RangeValues)?, void touchCallback(FlTouchEvent, LineTouchResponse?)?, String? xPrefix = '', String? prefix = '', String? suffix = '', bool showGridLines = false, bool showBorder = true, bool showSlider = true, AxisTitles? bottomTitles, AxisTitles? leftTitles, LineTouchTooltipData? touchTooltipData, String xAxisTitle = '', String yAxisTitle = '', List<BetweenBarsData> betweenBarsData = const [], Key? key})
const

Properties

betweenBarsData → List<BetweenBarsData>
final
bottomTitles → AxisTitles?
final
convertedValue → double Function(double)
Function to convert the value for display This is needed for converting numbers from a particular currency to another. If not needed, return the value as is.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftTitles → AxisTitles?
final
lineBarsData → List<LineChartBarData>
final
maxValue → double?
final
minValue → double?
final
onRangeChanged → void Function(RangeValues)?
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBorder → bool
final
showGridLines → bool
final
showSlider → bool
final
suffix → String?
final
toolTipKeys → List<Map<String, dynamic>>
final
touchCallback → void Function(FlTouchEvent, LineTouchResponse?)?
final
touchTooltipData → LineTouchTooltipData?
final
xAxisTitle → String
final
xPrefix → String?
final
yAxisTitle → String
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<S360fLineChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited