S360fScatterChart class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- S360fScatterChart
- Available extensions
Constructors
-
S360fScatterChart({required List<
ScatterFundData> data, Key? key, String? title, List<double> ? xAxisValues, List<double> ? yAxisValues, String xAxisTitle = 'Annual Volatility (%)', String yAxisTitle = 'Annual Return (%)', BoxDecoration? backgroundDecoration, EdgeInsetsGeometry padding = const EdgeInsets.all(8), void touchCallback(FlTouchEvent event, ScatterTouchResponse? response)?, ScatterTouchTooltipData? touchTooltipData}) -
const
Properties
- backgroundDecoration → BoxDecoration?
-
final
-
data
→ List<
ScatterFundData> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- touchCallback → void Function(FlTouchEvent event, ScatterTouchResponse? response)?
-
final
- touchTooltipData → ScatterTouchTooltipData?
-
final
- xAxisTitle → String
-
final
-
xAxisValues
→ List<
double> ? -
final
- yAxisTitle → String
-
final
-
yAxisValues
→ List<
double> ? -
final
Methods
-
animateOnActionTrigger(
AnimationInfo animationInfo, {List< Effect> ? effects, bool hasBeenTriggered = false}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
animateOnPageLoad(
AnimationInfo animationInfo, {List< Effect> ? effects}) → Widget -
Available on Widget, provided by the AnimatedWidgetExtension extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited