ScatterFundData class

Constructors

ScatterFundData({required Color color, required String fundId, required String fundName, required double fundWeight, required double fundRadius, required double annualReturn, required double annualVolatility})
ScatterFundData.fromJson(Map<String, dynamic> json)
factory

Properties

annualReturn → double
final
annualVolatility → double
final
color → Color
final
fundId → String
final
fundName → String
final
fundRadius → double
final
fundWeight → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited