S360fSelectableOptionsContainer class

Inheritance
Available extensions

Constructors

S360fSelectableOptionsContainer({required List<S360fSelectableOptionItem> items, Widget? itemBuilder(BuildContext context, int index)?, int cols = 2, double colSpacing = 0, double rowSpacing = 0, void onItemTap(Object id)?, void onDisableTap()?, bool disabled = false, double? extent, bool showCheckbox = false, Key? key})
const

Properties

cols → int
final
colSpacing → double
final
disabled → bool
final
extent → double?
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → Widget? Function(BuildContext context, int index)?
final
items → List<S360fSelectableOptionItem>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDisableTap → void Function()?
final
onItemTap → void Function(Object id)?
final
rowSpacing → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCheckbox → bool
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited