itemCount property
The number of cards to display in the table.
This determines how many times cardBuilder will be called.
Implementation
final int itemCount;
The number of cards to display in the table.
This determines how many times cardBuilder will be called.
final int itemCount;