dataCount property
The total number of data rows to display in the table.
This determines how many times tableDataBuilder and actionsBuilder will be called to generate the table content.
Implementation
final int dataCount;
The total number of data rows to display in the table.
This determines how many times tableDataBuilder and actionsBuilder will be called to generate the table content.
final int dataCount;