minWidth property
Optional minimum width constraint for the table.
When set, the table will not shrink below this width and will enable horizontal scrolling if the available space is less than minWidth. If not provided, the table will adapt to the available width.
Implementation
final double? minWidth;