onTap property

void Function(int) onTap
final

Callback function called when a table row is tapped.

The index parameter represents the row that was tapped (0-based). This can be used to navigate to detail pages or perform other row-level actions.

Implementation

final void Function(int) onTap;