tableHeaders property

List<S360fTableHeader> tableHeaders
final

The list of widgets to display as column headers.

The last widget in this list is treated as the header for the actions column. All other widgets represent data column headers.

Implementation

final List<S360fTableHeader> tableHeaders;