dateTime property

DateTime dateTime
final

The timestamp when this timeline entry occurred or was created.

This date/time is automatically formatted for display using the pattern: "Change On DD/MMM/YYYY At HH:MM"

Implementation

final DateTime dateTime;