DynamicCardFactory class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
createBasicCard({required String title, required String content, TextStyle? titleStyle, TextStyle? contentStyle, double elevation = 1.0, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin})
→ DynamicCardConfig
-
Creates a basic card with title and text content
-
createCustomCard({required Widget builder(BuildContext, Map<String, dynamic>?, dynamic (String, dynamic)?), String? title, TextStyle? titleStyle, double elevation = 1.0, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin})
→ DynamicCardConfig
-
Creates a custom card using a builder function
-
createGridCard({required String title, required List<CardContentItem> gridItems, int columns = 2, double childAspectRatio = 1.0, TextStyle? titleStyle, double elevation = 1.0, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin})
→ DynamicCardConfig
-
Creates a card with a grid layout
-
Creates a card with header section including icon and title
-
Creates a card with actions in the header
-
createTabbedCard({required String title, required List<CardTab> tabs, double? tabContentHeight, Color? tabLabelColor, Color? tabUnselectedLabelColor, Color? tabIndicatorColor, TextStyle? titleStyle, double elevation = 1.0, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin})
→ DynamicCardConfig
-
Creates a card with tabs
-
createTwoColumnCard({required String title, required List<CardContentItem> leftColumn, required List<CardContentItem> rightColumn, int leftFlex = 1, int rightFlex = 1, TextStyle? titleStyle, double elevation = 1.0, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin})
→ DynamicCardConfig
-
Creates a card with two columns