CardAction class

Constructors

CardAction({required String id, String? label, TextStyle? labelStyle, IconData? icon, Color? iconColor, double? iconSize, String? tooltip, dynamic data})
const
CardAction.fromJson(Map<String, dynamic> json)
factory

Properties

data → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconColor → Color?
final
iconSize → double?
final
id → String
final
label → String?
final
labelStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited