CardContentItem class

Constructors

CardContentItem({required ContentType type, String? text, TextStyle? textStyle, List<TextSpan>? richTextSpans, String? imageUrl, double? imageHeight, double? imageWidth, double? imageRadius, BoxFit? imageFit, ButtonStyle? buttonStyle, String? actionId, dynamic actionData, IconData? icon, Color? iconColor, double? iconSize, Widget? chartWidget, Color? dividerColor, double? dividerThickness, double? dividerHeight, List<CardContentItem>? listItems, Widget? customWidget, EdgeInsets? padding})
const
CardContentItem.fromJson(Map<String, dynamic> json)
factory

Properties

actionData → dynamic
final
actionId → String?
final
buttonStyle → ButtonStyle?
final
chartWidget → Widget?
final
customWidget → Widget?
final
dividerColor → Color?
final
dividerHeight → double?
final
dividerThickness → double?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconColor → Color?
final
iconSize → double?
final
imageFit → BoxFit?
final
imageHeight → double?
final
imageRadius → double?
final
imageUrl → String?
final
imageWidth → double?
final
listItems → List<CardContentItem>?
final
padding → EdgeInsets?
final
richTextSpans → List<TextSpan>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
textStyle → TextStyle?
final
type → ContentType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited