CardHeader class

Constructors

CardHeader({required String title, String? subtitle, IconData? icon, Color? iconColor, double? iconSize, String? avatarUrl, double? avatarRadius, TextStyle? titleStyle, TextStyle? subtitleStyle})
const
CardHeader.fromJson(Map<String, dynamic> json)
factory

Properties

avatarRadius → double?
final
avatarUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconColor → Color?
final
iconSize → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
final
subtitleStyle → TextStyle?
final
title → String
final
titleStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited