DynamicCardConfig class

Constructors

DynamicCardConfig({String? title, TextStyle? titleStyle, CardHeader? header, List<CardAction>? actions, List<CardContentItem>? content, List<CardTab>? tabs, List<CardContentItem>? leftColumn, List<CardContentItem>? rightColumn, int? leftColumnFlex, int? rightColumnFlex, int? gridColumns, double? gridChildAspectRatio, double? tabContentHeight, Color? tabLabelColor, Color? tabUnselectedLabelColor, Color? tabIndicatorColor, Widget customBuilder(BuildContext, Map<String, dynamic>?, dynamic (String, dynamic)?)?, double elevation = 1.0, double borderRadius = 8.0, double borderWidth = 1.0, Color? borderColor, Color backgroundColor = Colors.white, EdgeInsets? padding, EdgeInsets? margin, CardLayout layout = CardLayout.basic})
const
DynamicCardConfig.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<CardAction>?
final
backgroundColor → Color
final
borderColor → Color?
final
borderRadius → double
final
borderWidth → double
final
content → List<CardContentItem>?
final
customBuilder → Widget Function(BuildContext, Map<String, dynamic>?, dynamic (String, dynamic)?)?
final
elevation → double
final
gridChildAspectRatio → double?
final
gridColumns → int?
final
hashCode → int
The hash code for this object.
no setterinherited
final
layout → CardLayout
final
leftColumn → List<CardContentItem>?
final
leftColumnFlex → int?
final
margin → EdgeInsets?
final
padding → EdgeInsets?
final
rightColumn → List<CardContentItem>?
final
rightColumnFlex → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabContentHeight → double?
final
tabIndicatorColor → Color?
final
tabLabelColor → Color?
final
tabs → List<CardTab>?
final
tabUnselectedLabelColor → Color?
final
title → String?
final
titleStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited