S360fHorizontalBarChart class

Inheritance
Available extensions

Constructors

S360fHorizontalBarChart({required List<HorizontalBarChartItem> items, required double maxValue, Key? key, List<double>? xAxisValues, String currencySymbol = 'SGD', bool showValues = true, double width = double.infinity, double height = 200, EdgeInsets padding = const EdgeInsets.all(16), double barHeight = 40, double barGap = 8})
const

Properties

barGap double
Gap between bars
final
barHeight double
Height of individual bars
final
currencySymbol String
Currency symbol to display with values
final
hashCode int
The hash code for this object.
no setterinherited
height double
Height of the chart
final
items List<HorizontalBarChartItem>
The data to display in the chart
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue double
The maximum value for the x-axis
final
padding EdgeInsets
Padding around the chart
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValues bool
Whether to show values inside bars
final
width double
Width of the chart
final
xAxisValues List<double>?
X-axis values to display as labels
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited