S360fTextInput class

Inheritance
Mixed-in types
Available extensions

Constructors

S360fTextInput({required String label, required String hint, Key? key, dynamic value, TextEditingController? controller, FocusNode? focusNode, bool disabled = false, bool readOnly = false, VoidCallback? onTap, Widget? suffixIcon, String? errorMessage, bool isError = false, bool? isRequired = false, TextInputType? keyboardType, List<TextInputFormatter>? inputFormatters, String? validator(String?)?, ValueChanged<String>? onSubmitted, Iterable<String>? autofillHints, bool obscureText = false, ValueChanged? onChanged, TextCapitalization textCapitalization = TextCapitalization.none, bool autofocus = false, bool allowDecimal = true, String? prefix, String? suffix, int? maxDecimals, int? minLength, int? maxLength, double maxTextFieldHeight = 46.0, bool useNumericFormatter = false, String? tooltipMessage, Widget? tooltipIcon, Color? tooltipIconColor, Color? backgroundColor, Key? textFieldKey, BorderRadius? borderRadius})
const

Properties

allowDecimal → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
backgroundColor → Color?
final
borderRadius → BorderRadius?
final
controller → TextEditingController?
final
disabled → bool
final
errorMessage → String?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String
final
inputFormatters → List<TextInputFormatter>?
final
isError → bool
final
isRequired → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String
final
maxDecimals → int?
final
maxLength → int?
final
maxTextFieldHeight → double
final
minLength → int?
final
obscureText → bool
final
onChanged → ValueChanged?
final
onSubmitted → ValueChanged<String>?
final
onTap → VoidCallback?
final
prefix → String?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → String?
final
suffixIcon → Widget?
final
textCapitalization → TextCapitalization
final
textFieldKey → Key?
final
tooltipIcon → Widget?
final
tooltipIconColor → Color?
final
tooltipMessage → String?
final
useNumericFormatter → bool
final
validator → String? Function(String?)?
final
value → dynamic
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited