S360FDataCell class

Constructors

S360FDataCell({required Widget child, bool isPlaceholder = false, bool showEditIcon = false, VoidCallback? onTap, ValueChanged<TapDownDetails>? onTapDown, VoidCallback? onTapCancel, VoidCallback? onDoubleTap, VoidCallback? onLongPress, bool isOptional = false})
const

Properties

child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
isOptional → bool
final
isPlaceholder → bool
final
onDoubleTap → VoidCallback?
final
onLongPress → VoidCallback?
final
onTap → VoidCallback?
final
onTapCancel → VoidCallback?
final
onTapDown → ValueChanged<TapDownDetails>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showEditIcon → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDataCell({required double height, void onTap()?}) → DataCell
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited