S360FDataColumn class

Constructors

S360FDataColumn({required Widget label, bool isNumeric = false, String? tooltip, dynamic onSort(int, bool)?, TableColumnWidth? fixedWidth = const IntrinsicColumnWidth(flex: 1), bool isOptional = false})
const

Properties

fixedWidth → TableColumnWidth?
final
hashCode → int
The hash code for this object.
no setterinherited
isNumeric → bool
final
isOptional → bool
final
label → Widget
final
onSort → dynamic Function(int, bool)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDataColumn() → DataColumn
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited