S360FDataTable class

Inheritance
Available extensions

Constructors

S360FDataTable({required List<S360FDataColumn> columns, required List<S360FDataRow> rows, Key? key, double headingRowHeight = 56.0, double dataRowHeight = 48.0, double horizontalMargin = 24.0, double columnSpacing = 24.0, bool showCheckboxColumn = true, bool showBottomBorder = true, double rowPadding = 2.0})
const

Properties

columns → List<S360FDataColumn>
final
columnSpacing → double
final
dataRowHeight → double
final
hashCode → int
The hash code for this object.
no setterinherited
headingRowHeight → double
final
horizontalMargin → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rowPadding → double
final
rows → List<S360FDataRow>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBottomBorder → bool
final
showCheckboxColumn → bool
final

Methods

animateOnActionTrigger(AnimationInfo animationInfo, {List<Effect>? effects, bool hasBeenTriggered = false}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

animateOnPageLoad(AnimationInfo animationInfo, {List<Effect>? effects}) → Widget

Available on Widget, provided by the AnimatedWidgetExtension extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited