$AssetsSharedIconsGen class
Constructors
-
const
Properties
- balanceRisk → AssetGenImage
-
File path: assets/shared/icons/balance_risk.png
no setter
- filter → String
-
File path: assets/shared/icons/filter.svg
no setter
- fullScreen → String
-
File path: assets/shared/icons/full_screen.svg
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- highRisk → AssetGenImage
-
File path: assets/shared/icons/high_risk.png
no setter
- icSplash → AssetGenImage
-
File path: assets/shared/icons/icSplash.png
no setter
- lowRisk → AssetGenImage
-
File path: assets/shared/icons/low_risk.png
no setter
-
File path: assets/shared/icons/premium_image.png
no setter
- profilePlaceholder → AssetGenImage
-
File path: assets/shared/icons/profile_placeholder.png
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setting → String
-
File path: assets/shared/icons/setting.svg
no setter
- values → List
-
List of all assets
no setter
- veryLowRisk → AssetGenImage
-
File path: assets/shared/icons/very_low_risk.png
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited