actionsBuilder property
A function that builds the action widget for each row.
This function is called for each row (from 0todataCount-1) and should return a widget containing the actions available for that row, such as edit, delete, or view buttons.
Implementation
final ColumnActionBuilder? actionsBuilder;