columnFlex property
Defines the flex values for each column to control their relative widths.
This list should have the same length as tableHeaders. Each value determines the column's width:
- Positive values: Multiplied by the base width to determine column width
-1: Column uses auto-sizing (Expanded widget when not scrolling)
The last value in this list applies to the actions column, but actions column always uses a fixed width of 100 pixels regardless of this value.
Implementation
final List<double> columnFlex;