tableDataBuilder property
A function that builds the data widgets for each row.
This function is called for each row (from 0todataCount-1) and should return a list of widgets representing the data for each column (excluding the actions column). The returned list should have one widget for each data column (tableHeaders.length - 1).
Implementation
final TableDataBuilder tableDataBuilder;